@@ -3,17 +3,18 @@ BEGIN {
   $SHARYANTO::Dummy::Module1::VERSION = '0.01';
 }
 
-# VERSION
+sub from_dist2 {
+}
 
 1;
-# ABSTRACT: Dummy dist to test PAUSE indexing
+# ABSTRACT: Dummy dist to test PAUSE indexing, add functions to Module1
 
 __END__
 =pod
 
 =head1 NAME
 
-SHARYANTO::Dummy::Module1 - Dummy dist to test PAUSE indexing
+SHARYANTO::Dummy::Module1 - Dummy dist to test PAUSE indexing, add functions to Module1
 
 =head1 VERSION
 
